# idtrackerai-app

This module is part of [idtracker.ai](https://idtracker.ai/).

idtrackerai-app is a [Pyforms](https://idtrackerai.readthedocs.io/en/latest/how_to_install.html) based application that allows using [idtracker.ai](https://idtracker.ai/) from a GUI or from the command line.

To install and use idtracker.ai v3 through idtrackerai-app we recommend to follow the instructions in [the documentation](https://idtrackerai.readthedocs.io/en/latest/how_to_install.html).
